stravalib.client.Client.handle\_subscription\_callback
======================================================

.. currentmodule:: stravalib.client

.. automethod:: Client.handle_subscription_callback
